<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


add_filter( 'qmn_end_shortcode', 'qsm_user_dashboard_inline', 4, 10 );
if ( ! function_exists( 'qsm_user_dashboard_inline' ) ) {
	/**
	 * QSM breeze theme style
	 *
	 * @since 1.0.0
	 * @param object $qmn_quiz_options Quiz options.
	 * @return void
	 */
	function qsm_user_dashboard_inline( $return_display, $qmn_quiz_options, $qmn_array_for_variables, $shortcode_args ) {
		$quiz_settings = unserialize($qmn_quiz_options->quiz_settings);
		global $wpdb, $mlwQuizMasterNext;
		if((isset($qmn_quiz_options->end_quiz_if_wrong) && 0 == $qmn_quiz_options->end_quiz_if_wrong) || isset($qmn_quiz_options->enable_quick_result_mc) && 0 == $qmn_quiz_options->enable_quick_result_mc) {
			$qpages_arr = isset($quiz_settings['qpages']) ? maybe_unserialize($quiz_settings['qpages']) : array();
			$quiz_options = maybe_unserialize( $quiz_settings['quiz_options'] );
			$correct_answer_logic = isset($quiz_options['correct_answer_logic']) ? $quiz_options['correct_answer_logic'] : NULL;
			$encryption['correct_answer_logic'] = $correct_answer_logic;
			$enc_questions = array();
			if ( ! empty( $qpages_arr ) ) {
				foreach ( $qpages_arr as $item ) {
					$enc_questions = array_merge($enc_questions, $item['questions']);
				}
			}
			$enc_questions = implode(',', $enc_questions);
			$question_array = $wpdb->get_results(
				"SELECT quiz_id, question_id, answer_array, question_answer_info, question_type_new, question_settings
				FROM {$wpdb->prefix}mlw_questions
				WHERE question_id IN ($enc_questions)", ARRAY_A);
			foreach ( $question_array as $key => $question ) {
				$encryption[ $question['question_id'] ]['question_type_new'] = $question['question_type_new'];
				$encryption[ $question['question_id'] ]['answer_array'] = maybe_unserialize( $question['answer_array'] );
				$encryption[ $question['question_id'] ]['settings'] = maybe_unserialize( $question['question_settings'] );
				$encryption[ $question['question_id'] ]['correct_info_text'] = isset( $question['question_answer_info'] ) ? html_entity_decode( $question['question_answer_info'] ) : '';
				$encryption[ $question['question_id'] ]['correct_info_text'] = $mlwQuizMasterNext->pluginHelper->qsm_language_support( $encryption[ $question['question_id'] ]['correct_info_text'], "correctanswerinfo-{$question['question_id']}" );
			}
			$qsm_inline_encrypt_js = '
			var encryptionKey = "'.hash('sha256',time()).'";
			var data = '.wp_json_encode($encryption).';
			var jsonString = JSON.stringify(data);
			var encryptedData = CryptoJS.AES.encrypt(jsonString, encryptionKey).toString();';
			wp_add_inline_script('qsm_encryption', $qsm_inline_encrypt_js, 'after');
		}
		$quiz_inline_results_count = 0;
		if(isset($quiz_settings['quiz_inline_results'])) {
			$quiz_inline_results_count = $quiz_settings['quiz_inline_results']['quiz_inline_results_count'];
		}
		$inline_dashboard = 0;
		if(isset($quiz_inline_results_count) && 1 == $quiz_inline_results_count) {
			wp_enqueue_style( 'qsm_user-dashboard_css', QSM_USER_DASHBOARD_URL . '/qsm-user-dashboard-style.css', array(), QSM_USER_DASHBOARD_VERSION );
			wp_enqueue_script( 'qsm_user-dashboard_js', QSM_USER_DASHBOARD_URL . '/qsm-user-dashboard.js', array( 'jquery' ), QSM_USER_DASHBOARD_VERSION, true );
			$inline_dashboard = $quiz_inline_results_count;
		}
		wp_localize_script( 'qsm_user-dashboard_js', 'inline_dashboard', array( 'inline_dashboard' => $inline_dashboard ) );

		return $return_display;
	}
}

/**
 * Registers your tab in the addon settings page
 *
 * @since 1.1.1
 * @return void
 */
function qsm_addon_user_dashboard_register_addon_settings_tabs() {
	global $mlwQuizMasterNext;
	if ( ! is_null( $mlwQuizMasterNext ) && ! is_null( $mlwQuizMasterNext->pluginHelper ) && method_exists( $mlwQuizMasterNext->pluginHelper, 'register_quiz_settings_tabs' ) ) {
		$mlwQuizMasterNext->pluginHelper->register_addon_settings_tab( "User Dashboard Settings", 'qsm_addon_user_dashboard_addon_settings_tabs_content' );
	}
}

/**
 * Generates the content for your addon settings tab
 *
 * @since 1.1.1
 * @return void
 */
function qsm_addon_user_dashboard_addon_settings_tabs_content() {
	
	wp_enqueue_script( 'qsm_user-dashboard_js', QSM_USER_DASHBOARD_URL . '/qsm-user-dashboard.js', array( 'jquery' ), QSM_USER_DASHBOARD_VERSION, true );
	$settings	 = get_option('mlw_qmn_dashboard_option', '');
	global $mlwQuizMasterNext;
	$default_notice = 1;
	$license		 = isset( $settings['license_key'] ) ? trim( $settings['license_key'] ) : '';
	$license_status	 = isset( $settings['license_status'] ) ? $settings['license_status'] : '';
	//If nonce is correct, update settings from passed input
	if (isset($_POST["user_dashboard_nonce"]) && wp_verify_nonce($_POST['user_dashboard_nonce'], 'user_dashboard')) {
		// Load previous license key.
		
		$saved_license	 = isset($_POST['license_key']) ? sanitize_text_field(wp_unslash($_POST['license_key'])) : '';
		$new_settings	 = array(
			'license_key'					 => $saved_license,
			'quiz_name_check'				 => isset($_POST["quiz_name_check"]) ? 1 : 0,
			'quiz_name_text'				 => sanitize_text_field($_POST["quiz_name_text"]),
			'quiz_score_check'				 => isset($_POST["quiz_score_check"]) ? 1 : 0,
			'quiz_score_text'				 => sanitize_text_field($_POST["quiz_score_text"]),
			'quiz_time_check'				 => isset($_POST["quiz_time_check"]) ? 1 : 0,
			'quiz_time_text'				 => sanitize_text_field($_POST["quiz_time_text"]),
			'quiz_time_to_complete_check'	 => isset($_POST["quiz_time_to_complete_check"]) ? 1 : 0,
			'quiz_certificate_link_check'	 => isset($_POST["quiz_certificate_link_check"]) ? 1 : 0,
			'quiz_time_to_complete_text'	 => sanitize_text_field($_POST["quiz_time_to_complete_text"]),
			'quiz_certificate_link_text'	 => sanitize_text_field($_POST["quiz_certificate_link_text"]),
			'quiz_back_button_text'			 => sanitize_text_field($_POST["quiz_back_button_text"]),
			'results_template'				 => wp_kses_post(stripslashes($_POST["results_template"])),
			'next_button_text'				 => sanitize_text_field($_POST["next_button_text"]),
			'previous_button_text'			 => sanitize_text_field($_POST["previous_button_text"]),
			'view_text'						 => sanitize_text_field($_POST["view_text"]),
			'not_user_text'					 => sanitize_text_field($_POST["not_user_text"]),
		);
		// Checks to see if the license key has changed.
		// if ($license !== $saved_license) {
			if( class_exists ( 'QSM_Check_License' )) {
				$activation = $mlwQuizMasterNext->check_license->activate( $saved_license, 'User Dashboard' );
			}else{
				$activation = QSM_license::activate( $saved_license, 'User Dashboard' );
			}
			
			if( !empty($activation) && ( ( __( 'Attempting to activate a bundle\'s parent license', 'qsm-user-dashboard' ) == $activation['message'] || __( 'License key revoked', 'qsm-user-dashboard' ) == $activation['message'] || __( 'No activations left', 'qsm-user-dashboard' ) == $activation['message'] || __( 'License has expired', 'qsm-user-dashboard' ) == $activation['message'] ) || 'success' == $activation['status'] ) ) {
				$item_url = 'https://quizandsurveymaster.com/checkout/?edd_license_key='.$license.'&download_id='.USER_DASHBOARD_ITEM;
				$new_settings['license_key'] = $saved_license;
				$new_settings['license_status'] = 'valid';
				$new_settings['last_validate'] = date("d-m-Y", time());
				$new_settings['expiry_date'] = isset($activation['expiry_date']) ? $activation['expiry_date'] : "";
				if('success' == $activation['status']) {
					$mlwQuizMasterNext->alertManager->newAlert( __( 'License validated Successfully', 'qsm-user-dashboard' ), 'success' );
				}elseif(__( 'License has expired', 'qsm-user-dashboard' ) == $activation['message'] ){
					$target_text =  __('License Key Expired. ', 'qsm-user-dashboard');
					$target_link = sprintf( $target_text.'<a href="%s" target="_blank">%s</a>', esc_url( $item_url ), __( 'Click here to renew', 'qsm-user-dashboard' ) );
					$default_notice = 0;
					$mlwQuizMasterNext->alertManager->newAlert( $target_link, 'error' );
				}else{
					$mlwQuizMasterNext->alertManager->newAlert( $activation['message'], 'error' );
				}
				$mlwQuizMasterNext->alertManager->newAlert(__('Your settings has been saved successfully!', 'qsm-user-dashboard'), 'success');
			} else {
				$new_settings['license_key'] = '';
				$new_settings['license_status'] = '';
				$new_settings['last_validate'] = 'invalid';
				$new_settings['expiry_date'] = '';
				if( "" == $saved_license ) {
					$default_notice = 0;
					$mlwQuizMasterNext->alertManager->newAlert( __('License Key Required ', 'qsm-user-dashboard'), 'error' );
				}else{
					$mlwQuizMasterNext->alertManager->newAlert( $activation['message'], 'error' );
				}
			}
			// If same license key was entered.
			if($license != $saved_license) {
				$deactivation = QSM_license::deactivate( $license, 'User Dashboard' );
			}
		// }
		update_option('mlw_qmn_dashboard_option', $new_settings);
		
	}
	
	$date_now = date("d-m-Y");
	$settings	 = get_option('mlw_qmn_dashboard_option', '');
	$license		 = isset( $settings['license_key'] ) ? trim( $settings['license_key'] ) : '';
	$license_status	 = isset( $settings['license_status'] ) ? $settings['license_status'] : '';
	if( '' != $license && 'valid' == $license_status ) {
		if ( version_compare( $mlwQuizMasterNext->version, '8.1.6', '>' ) && (isset($settings['expiry_date']) && "" != $settings['expiry_date']) && (isset($settings['last_validate']) && "" != $settings['last_validate']) && strtotime($date_now) > strtotime($settings['expiry_date']) && strtotime($date_now) >= strtotime($settings['last_validate']) && 1 == $default_notice ) { 
			$item_url = 'https://quizandsurveymaster.com/checkout/?edd_license_key='.$license.'&download_id='.USER_DASHBOARD_ITEM;
			$target_text =  __('License Key Expired. ', 'qsm-user-dashboard');
			$target_link = sprintf( $target_text.'<a style="font-weight: 500;" href="%s" target="_blank">%s</a>', esc_url( $item_url ), __( 'Click here to renew', 'qsm-user-dashboard' ) );
			$mlwQuizMasterNext->alertManager->newAlert( $target_link, 'error' );
		}

		// Load settings
		$results_template	 = '<h1>Quiz Results</h1>
		You scored %CORRECT_SCORE%!

		Out of %TOTAL_QUESTIONS%, you got %AMOUNT_CORRECT% correct. Here are your answers:

		%QUESTIONS_ANSWERS%';
		$user_dashboard_data = wp_parse_args(
			get_option('mlw_qmn_dashboard_option', array()),
			array(
			'license_key'					 => '',
			'quiz_name_check'				 => 1,
			'quiz_name_text'				 => __("Quiz Name", "qsm-user-dashboard"),
			'quiz_score_check'				 => 1,
			'quiz_score_text'				 => __("Score", "qsm-user-dashboard"),
			'quiz_time_check'				 => 1,
			'quiz_time_text'				 => __("Time Taken", "qsm-user-dashboard"),
			'quiz_time_to_complete_check'	 => 1,
			'quiz_certificate_link_check'	 => 0,
			'quiz_time_to_complete_text'	 => __("Time to Complete", "qsm-user-dashboard"),
			'quiz_certificate_link_text'	 => __("Certificate Link", "qsm-user-dashboard"),
			'quiz_back_button_text'			 => __('Go Back', 'qsm-user-dashboard'),
			'results_template'				 => $results_template,
			'next_button_text'				 => __('Next 10 Results', 'qsm-user-dashboard'),
			'previous_button_text'			 => __('Previous 10 Results', 'qsm-user-dashboard'),
			'view_text'						 => __('View', 'qsm-user-dashboard'),
			'not_user_text'					 => __('You must be logged in to see your results.', 'qsm-user-dashboard'),
			)
		);
		$mlwQuizMasterNext->alertManager->showAlerts();
		?>
		<div class="wrap">
			<h2><?php _e('User Dashboard Settings', 'qsm-user-dashboard'); ?></h2>
			<p><?php echo sprintf(esc_html__('For users with access to the dashboard, they can visit their results with the new My Results page. For those without access to the dashboard, create a new post or page and insert the shortcode %s into it.', 'qsm-user-dashboard'), '[user_dashboard]'); ?></p>
			<form method="post" action="">
				<?php wp_nonce_field('user_dashboard', 'user_dashboard_nonce'); ?>
				<table class="form-table" style="width: 100%;">
					<tr valign="top">
						<th scope="row"><label for="license_key"><?php _e('Addon License Key', 'qsm-user-dashboard'); ?></label></th>
						<td><input type="text" name="license_key" id="license_key" value="<?php echo $user_dashboard_data["license_key"]; ?>"></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Show Quiz Name?', 'qsm-user-dashboard'); ?></th>
						<td><input name="quiz_name_check" type="checkbox" value="1" <?php checked('1', $user_dashboard_data['quiz_name_check']); ?> /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For Quiz Name Column', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="quiz_name_text" value="<?php echo $user_dashboard_data['quiz_name_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Show Score?', 'qsm-user-dashboard'); ?></th>
						<td><input name="quiz_score_check" type="checkbox" value="1" <?php checked('1', $user_dashboard_data['quiz_score_check']); ?> /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For Score Column', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="quiz_score_text" value="<?php echo $user_dashboard_data['quiz_score_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Show Time Taken?', 'qsm-user-dashboard'); ?></th>
						<td><input name="quiz_time_check" type="checkbox" value="1" <?php checked('1', $user_dashboard_data['quiz_time_check']); ?> /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For Time Taken Column', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="quiz_time_text" value="<?php echo $user_dashboard_data['quiz_time_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Show Time to Complete?', 'qsm-user-dashboard'); ?></th>
						<td><input name="quiz_time_to_complete_check" type="checkbox" value="1" <?php checked('1', $user_dashboard_data['quiz_time_to_complete_check']); ?> /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For Time to Complete', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="quiz_time_to_complete_text" value="<?php echo $user_dashboard_data['quiz_time_to_complete_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Show Certificate link?', 'qsm-user-dashboard'); ?>
							<p class="description"><?php _e('Note: QSM Certificate addon must be enable.', 'qsm-user-dashboard'); ?></p>
						</th>
						<td><input name="quiz_certificate_link_check" type="checkbox" value="1" <?php checked('1', $user_dashboard_data['quiz_certificate_link_check']); ?> /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For Certificate Link', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="quiz_certificate_link_text" value="<?php echo $user_dashboard_data['quiz_certificate_link_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For Back Button', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="quiz_back_button_text" value="<?php echo $user_dashboard_data['quiz_back_button_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For Next Button', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="next_button_text" value="<?php echo $user_dashboard_data['next_button_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For Previous Button', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="previous_button_text" value="<?php echo $user_dashboard_data['previous_button_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For View Link', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="view_text" value="<?php echo $user_dashboard_data['view_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Text For When User Is Not Logged In', 'qsm-user-dashboard'); ?></th>
						<td><input type="text" name="not_user_text" value="<?php echo $user_dashboard_data['not_user_text']; ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"><?php _e('Results Template', 'qsm-user-dashboard'); ?></th>
						<td><textarea id="qsm_results_template" cols="80" rows="15" name="results_template"><?php echo $user_dashboard_data['results_template']; ?></textarea></td>
					</tr>
				</table>
				<button class="button-primary"><?php _e('Save Changes', 'qsm-user-dashboard'); ?></button>
			</form>
		</div>
		<?php
	}else{
		$params		 = array(
			'please_wait'    => __('Please Wait...', 'qsm-user-dashboard'),
			'license_msg'    => __('License Key Required.', 'qsm-user-dashboard'),
		);
		wp_localize_script( 'qsm_user-dashboard_js', 'qsm_user_dashboard_obj', $params );
		$mlwQuizMasterNext->alertManager->showAlerts();?>
		<div class="license_form_parent">
			<div id="license_message" style="display: none;" class="error below-h2"><p><strong class="qsm_user_dashboard_validate_message"></strong></div>
			<h4><strong><?php esc_html_e( 'Please validate your licence key. ', 'qsm-user-dashboard' ); ?></strong></h4>
			<div class="qsm_user_dashboard_validate_parent">
				<form class="rq_validata-license" method="POST">
					<input type="text" placeholder="<?php echo esc_html("Enter your license key"); ?>" class="qsm_user_dashboard_validate_input" name="qsm_user_dashboard_validate_input" />
					<input type="submit" name="qsm_user_dashboard_validate_button" class="qsm_user_dashboard_validate_button button button-primary" />
				</form>
			</div>
		</div>
		<?php
	}
	
}
