<?php

/**
 * Creates the shortcode that outputs the table and results
 *
 * @since 1.1.0
 */
function qsm_user_dashboard_shortcode() {
	ob_start();
	// If the user isn't logged in
	if ( ! is_user_logged_in() ) {

		// Return the text from the settings
		$options = get_option( 'mlw_qmn_dashboard_option' );
		return $options['not_user_text'];
	}
	wp_enqueue_script( 'jquery' );	
	wp_enqueue_style( 'qmn_quiz_common_style', QSM_PLUGIN_URL . '/css/common.css' );
	$customStyle = ".question-type-polar-s .ui-widget-content { position: relative;}";
	wp_add_inline_style( 'qmn_quiz_common_style', $customStyle );
	
	wp_register_script( 'qsm-user-dashboard', '', array( 'jquery-ui-slider' ), '', true );
	wp_enqueue_script( 'qsm-user-dashboard' );
	?>
	<script type="text/javascript" async src="//cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.2/MathJax.js?config=TeX-MML-AM_CHTML"></script>

	<script>
		MathJax = {
		showProcessingMessages: false,
		tex2jax: { inlineMath: [['$','$'],['\\(','\\)']] }
		};
	</script>

<?php
	global $wpdb;

	// Gets total results
	$current_user  = wp_get_current_user();
	$table_limit   = 10;
	$results_count = $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(result_id) FROM ' . $wpdb->prefix . "mlw_results WHERE deleted='0' AND (user=%d OR email='%s')", get_current_user_id(), $current_user->user_email ) );

	// Sees what page we are on
	if ( isset( $_GET['result_page'] ) ) {
		$result_page  = $_GET['result_page'] + 1;
		$result_begin = $table_limit * $result_page;
	} else {
		$result_page  = 0;
		$result_begin = 0;
	}

	// Creates the amount to retreive and then retreives the results
	$results_remaining = $results_count - ( $result_page * $table_limit );
	$user_results      = $wpdb->get_results( $wpdb->prepare( 'SELECT results.*, quiz.quiz_settings FROM ' . $wpdb->prefix . 'mlw_results as results INNER join ' . $wpdb->prefix . "mlw_quizzes quiz on results.quiz_id = quiz.quiz_id WHERE results.deleted='0' AND  (results.user=%d OR results.email='%s') ORDER BY results.result_id DESC LIMIT %d, %d", get_current_user_id(), $current_user->user_email, $result_begin, $table_limit ) );
	$display      = '';
	$options      = get_option( 'mlw_qmn_dashboard_option' );
	$results_json = array();
	// Cycles through the results
	foreach ( $user_results as $result ) {

		// Prepares the template for the results
		$template = $options['results_template'];

		// For backwards compatibility
		$template = str_replace( '%QUESTIONS_RESULTS%', '%QUESTIONS_ANSWERS%', $template );

		if ( is_serialized( $result->quiz_results ) && is_array( @unserialize( $result->quiz_results ) ) ) {
			$results = unserialize( $result->quiz_results );
		} else {
			$template = str_replace( '%QUESTIONS_ANSWERS%', $result->quiz_results, $template );
			$template = str_replace( '%TIMER%', '', $template );
			$template = str_replace( '%COMMENT_SECTION%', '', $template );
			$results  = array(
				0,
				array(),
				'',
			);
		}
		// Creates the array for the template variables
		$qmn_array_for_variables = array(
			'result_id'                 => $result->result_id,
			'quiz_id'                   => $result->quiz_id,
			'quiz_name'                 => $result->quiz_name,
			'quiz_system'               => $result->quiz_system,
			'user_name'                 => $result->name,
			'user_business'             => $result->business,
			'user_email'                => $result->email,
			'user_phone'                => $result->phone,
			'user_id'                   => $result->user,
			'timer'                     => $results[0],
			'time_taken'                => $result->time_taken,
			'total_points'              => $result->point_score,
			'total_score'               => $result->correct_score,
			'total_correct'             => $result->correct,
			'total_questions'           => $result->total,
			'comments'                  => $results[2],
			'question_answers_array'    => $results[1],
			'form_type'                 => isset( $result->form_type ) ? $result->form_type : 0,
			'quiz_settings'             => isset( $result->quiz_settings ) ? @unserialize( $result->quiz_settings ) : array(),
			'total_possible_points'     => isset( $results['total_possible_points'] ) ? $results['total_possible_points'] : '',
			'total_attempted_questions' => isset( $results['total_attempted_questions'] ) ? $results['total_attempted_questions'] : '',
		);
		$template                = apply_filters( 'mlw_qmn_template_variable_results_page', $template, $qmn_array_for_variables );
		$template                = str_replace( "\n", '<br>', $template );
		$template                = do_shortcode( $template, true );
		// Creates JS object with all the results
		$results_json[ $result->result_id ] = $template;
	}
	$quiz_back_button_text                 = isset( $options['quiz_back_button_text'] ) ? $options['quiz_back_button_text'] : __( 'Go Back', 'qsm-user-dashboard' );
	$options['quiz_time_to_complete_text'] = isset( $options['quiz_time_to_complete_text'] ) ? $options['quiz_time_to_complete_text'] : __( 'Time to Complete', 'qsm-user-dashboard' );
	$options['quiz_certificate_link_text'] = isset( $options['quiz_certificate_link_text'] ) ? $options['quiz_certificate_link_text'] : __( 'Certificate Link', 'qsm-user-dashboard' );
$data = "
	function show_results(id) {
		jQuery('.qsm_results_table').hide();
		jQuery('.qsm_results').empty();
		jQuery('.qsm_results').html(
			'<button class=\"button\" onclick=\"qsm_show_results_table();\">". $quiz_back_button_text ."</button>' +
			qsm_results[id]);
		jQuery('.qsm_results').show();
		jQuery(document).trigger('qsm_init_after_result_show', [id,qsm_results]);
		MathJax.Hub.Queue([\"Typeset\", MathJax.Hub, jQuery('#qsm_ud_results').html()]);
		jQuery('.question-type-polar-s').each(function(){
			let question = jQuery(this).find('.slider-main-wrapper div');
			let minVal = question.data('answer1'); 
			let maxVal = question.data('answer2'); 
			let userVal = question.data('answer_value');
			question.slider({
				min: minVal,
				max: maxVal,
				value: userVal,
				disabled: true, // Set the slider to be disabled
				create: function (event, ui){
					// jQuery(document).trigger('qsm_after_display_result',[ this, ui ]);
					jQuery(this).find('span').css({'display':'flex','align-items':'center','justify-content':'center','text-decoration':'none','color':'white','height':'20px','background':'#a5a5a5','position':'absolute','margin-top':'6px'});
					jQuery(this).find('span').html('<p style=\"margin:0;height:25px;background: #6a6a7c;padding:5px;font-weight:bold;\">'+userVal+'</p>');					
				}
			});
		});		
	}	
	function qsm_show_results_table() {
		jQuery('.qsm_results').hide();
		jQuery('.qsm_results_table').show();
	}var qsm_results =". json_encode( $results_json );
wp_add_inline_script( 'qsm-user-dashboard', $data, 'after' );
?>
<div class="qsm_results" id="qsm_ud_results" style="display: none;"></div>
<div class="qsm_results_table">
	<?php
	if ( is_admin() ) {
		$admin_page = 'page=qsm_user_dashboard_admin_menu&&';
	} else {
		$admin_page = '';
	}
	if ( $theme_template = locate_template( '/qsm-templates/user-dashboard.php' ) ) {
		include $theme_template;
	} else {
		include QSM_USER_DASHBOARD_TEMPLATE_DIR . '/user-dashboard.php';
	}
	?>
</div>
<?php
	return ob_get_clean();
}
?>